@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2014-2020 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2014-2021 -- leonerd@leonerd.org.uk
 
 use v5.26;
-use Object::Pad 0.19;
+use Object::Pad 0.57;
 
-package Device::Chip::nRF24L01P 0.05;
+package Device::Chip::nRF24L01P 0.06;
 class Device::Chip::nRF24L01P
-   extends Device::Chip;
+   :isa(Device::Chip);
 
 use Carp;
 use Data::Bitfield qw( bitfield boolfield enumfield intfield );
